pub fn entity_layout(kind: EntityKind) -> Option<&'static EntityLayout>Expand description
The decode layout for kind, or None for kinds with no field
layout (e.g. Condition, which isn’t a server entity).
pub fn entity_layout(kind: EntityKind) -> Option<&'static EntityLayout>The decode layout for kind, or None for kinds with no field
layout (e.g. Condition, which isn’t a server entity).